@@ -103,9 +103,10 @@ def service_get_all(context, disabled=None):
     return IMPL.service_get_all(context, disabled)
 
 
-def service_get_all_by_topic(context, topic):
+def service_get_all_by_topic(context, topic, consider_disabled=False):
     """Get all services for a given topic."""
-    return IMPL.service_get_all_by_topic(context, topic)
+    return IMPL.service_get_all_by_topic(context, topic,
+                                         consider_disabled=consider_disabled)
 
 
 def service_get_all_share_sorted(context):
@@ -1008,6 +1009,13 @@ def export_location_metadata_get(context, export_location_uuid):
     return IMPL.export_location_metadata_get(context, export_location_uuid)
 
 
+def export_location_metadata_get_item(context, export_location_uuid, key):
+    """Get metadata item for a share export location."""
+    return IMPL.export_location_metadata_get_item(context,
+                                                  export_location_uuid,
+                                                  key)
+
+
 def export_location_metadata_delete(context, export_location_uuid, keys):
     """Delete metadata of an export location."""
     return IMPL.export_location_metadata_delete(
@@ -1020,6 +1028,14 @@ def export_location_metadata_update(context, export_location_uuid, metadata,
     return IMPL.export_location_metadata_update(
         context, export_location_uuid, metadata, delete)
 
+
+def export_location_metadata_update_item(context, export_location_uuid,
+                                         metadata):
+    """Update metadata item if it exists, otherwise create it."""
+    return IMPL.export_location_metadata_update_item(context,
+                                                     export_location_uuid,
+                                                     metadata)
+
 ####################
 
 
@@ -1322,6 +1338,12 @@ def share_server_backend_details_set(context, share_server_id, server_details):
                                                  server_details)
 
 
+def share_server_backend_details_get_item(context, share_server_id, meta_key):
+    """Get backend details."""
+    return IMPL.share_server_backend_details_get_item(context, share_server_id,
+                                                      meta_key)
+
+
 def share_server_backend_details_delete(context, share_server_id):
     """Delete backend details DB records for a share server."""
     return IMPL.share_server_backend_details_delete(context, share_server_id)
