@@ -20,11 +20,8 @@
 Manage hosts in the current zone.
 """
 
+import collections
 import re
-try:
-    from UserDict import IterableUserDict  # noqa
-except ImportError:
-    from collections import UserDict as IterableUserDict  # noqa
 
 from oslo_config import cfg
 from oslo_log import log
@@ -86,7 +83,7 @@ CONF.import_opt('max_over_subscription_ratio', 'manila.share.driver')
 LOG = log.getLogger(__name__)
 
 
-class ReadOnlyDict(IterableUserDict):
+class ReadOnlyDict(collections.UserDict):
     """A read-only dict."""
 
     def __init__(self, source=None):
@@ -111,7 +108,7 @@ class ReadOnlyDict(IterableUserDict):
     def update(self, source=None):
         if source is None:
             return
-        elif isinstance(source, IterableUserDict):
+        elif isinstance(source, collections.UserDict):
             self.data = source.data
         elif isinstance(source, type({})):
             self.data = source
@@ -626,18 +623,23 @@ class HostManager(object):
                   {'service_name': service_name, 'host': host,
                    'cap': capabilities})
 
-    def _update_host_state_map(self, context):
-
+    def _update_host_state_map(self, context, consider_disabled=False):
         # Get resource usage across the available share nodes:
         topic = CONF.share_topic
-        share_services = db.service_get_all_by_topic(context, topic)
+        share_services = db.service_get_all_by_topic(
+            context,
+            topic,
+            consider_disabled=consider_disabled,
+        )
 
         active_hosts = set()
         for service in share_services:
             host = service['host']
 
             # Warn about down services and remove them from host_state_map
-            if not utils.service_is_up(service) or service['disabled']:
+            is_down = not utils.service_is_up(service)
+            is_disabled = (not consider_disabled and service['disabled'])
+            if is_down or is_disabled:
                 LOG.warning("Share service is down. (host: %s).", host)
                 continue
 
@@ -663,7 +665,7 @@ class HostManager(object):
                      "scheduler cache.", {'host': host})
             self.host_state_map.pop(host, None)
 
-    def get_all_host_states_share(self, context):
+    def get_all_host_states_share(self, context, consider_disabled=False):
         """Returns a dict of all the hosts the HostManager knows about.
 
         Each of the consumable resources in HostState are
@@ -673,7 +675,10 @@ class HostManager(object):
           {'192.168.1.100': HostState(), ...}
         """
 
-        self._update_host_state_map(context)
+        self._update_host_state_map(
+            context,
+            consider_disabled=consider_disabled,
+        )
 
         # Build a pool_state map and return that map instead of host_state_map
         all_pools = {}
